==> rh-quarkus-1.7.6-src.zip: rh-quarkus-1.7.6.GA-src/io.quarkus-quarkus-parent-1.7.6/integration-tests/elytron-undertow/src/test/java/io/quarkus/it/undertow/elytron/ServletSecurityAnnotationPermissionsTestCase.java <==
package io.quarkus.it.undertow.elytron;

import static io.restassured.RestAssured.given;

import org.junit.jupiter.api.Test;

import io.quarkus.test.junit.QuarkusTest;

@QuarkusTest
class ServletSecurityAnnotationPermissionsTestCase {

    @Test
    void testSecuredServletWithWrongAuth() {
        given()
                .header("Authorization", "Basic am9objpqb2hu")
                .when()
                .get("/foo/annotation-secure")
                .then()
                .statusCode(403);
    }

    @Test
    void testSecuredServletWithNoAuth() {
        given()
                .when()
                .get("/foo/annotation-secure")
                .then()
                .statusCode(401);
    }

    @Test
    void testSecuredServletWithAuth() {
        given()
                .auth()
                .basic("mary", "mary")
                .when()
                .get("/foo/annotation-secure")
                .then()
                .statusCode(200);
    }

    @Test
    void testEmptyRolesPermit() {
        given()
                .when()
                .put("/foo/annotation-secure")
                .then()
                .statusCode(200);
    }

    @Test
    void testEmptyRolesDeny() {
        given()
                .when()
                .delete("/foo/annotation-secure")
                .then()
                .statusCode(401);
    }

    @Test
    void testPostDeniedWrongRole() {
        given()
                .auth()
                .basic("mary", "mary")
                .when()
                .post("/foo/annotation-secure")
                .then()
                .statusCode(403);
    }

    @Test
    void testPostSucess() {
        given()
                .when()
                .body("tmp")
                .auth()
                .basic("poul", "poul")
                .post("/foo/annotation-secure")
                .then()
                .statusCode(200);
    }
}

==> rh-quarkus-2.2.5-src.zip: rh-quarkus-2.2.5.GA-src/io.quarkus-quarkus-parent-2.2.5/integration-tests/elytron-undertow/src/test/java/io/quarkus/it/undertow/elytron/ServletSecurityAnnotationPermissionsTestCase.java <==
package io.quarkus.it.undertow.elytron;

import static io.restassured.RestAssured.given;

import org.junit.jupiter.api.Test;

import io.quarkus.test.junit.QuarkusTest;

@QuarkusTest
class ServletSecurityAnnotationPermissionsTestCase extends HttpsSetup {

    @Test
    void testSecuredServletWithWrongAuth() {
        given()
                .header("Authorization", "Basic am9objpqb2hu")
                .when()
                .get("/foo/annotation-secure")
                .then()
                .statusCode(403);
    }

    @Test
    void testSecuredServletWithNoAuth() {
        given()
                .when()
                .get("/foo/annotation-secure")
                .then()
                .statusCode(401);
    }

    @Test
    void testSecuredServletWithAuth() {
        given()
                .auth()
                .basic("mary", "mary")
                .when()
                .get("/foo/annotation-secure")
                .then()
                .statusCode(200);
    }

    @Test
    void testEmptyRolesPermit() {
        given()
                .when()
                .put("/foo/annotation-secure")
                .then()
                .statusCode(200);
    }

    @Test
    void testEmptyRolesDeny() {
        given()
                .when()
                .delete("/foo/annotation-secure")
                .then()
                .statusCode(401);
    }

    @Test
    void testPostDeniedWrongRole() {
        given()
                .auth()
                .basic("mary", "mary")
                .when()
                .post("/foo/annotation-secure")
                .then()
                .statusCode(403);
    }

    @Test
    void testPostSucess() {
        given()
                .when()
                .body("tmp")
                .auth()
                .basic("poul", "poul")
                .post("/foo/annotation-secure")
                .then()
                .statusCode(200);
    }
}
